import { BaseStatusDto } from 'src/core/modules/infrastructure/dto/base-status.dto';
import { ItemCategoryEntity } from '../../domain/entities/item-category.entity';
import { IsEnum, IsString, ValidateIf } from 'class-validator';
import { ItemType } from '../../constants';
import { ApiProperty } from '@nestjs/swagger';

export class ItemCategoryDto
  extends BaseStatusDto
  implements ItemCategoryEntity
{
  @ApiProperty({ name: 'name', required: true, example: 'Bundling w Entrance' })
  @IsString()
  name: string;

  @ApiProperty({
    type: 'string',
    required: false,
    description: `Select (${JSON.stringify(Object.values(ItemType))})`,
    example: ItemType.BUNDLING,
  })
  @ValidateIf((body) => body.order_type)
  @IsEnum(ItemType, {
    message: `must be a valid enum ${JSON.stringify(Object.values(ItemType))}`,
  })
  item_type: ItemType;
}
